@@ -390,7 +390,8 @@ class YouTubeMain(Screen):
 		self.onLayoutFinish.append(self.layoutFinish)
 		self.onClose.append(self.cleanVariables)
 		for p in plugins.getPlugins(where=PluginDescriptor.WHERE_MENU):
-			if 'ServiceApp' in p.path:
+			# TRANSLATORS: Don't translate this! It is used as a variable, so it must be equal to the translation in the plugin!
+			if p.name == _('ServiceApp'):
 				break
 		else:
 			config.plugins.YouTube.player.value = '4097'
@@ -1503,7 +1504,8 @@ class YouTubeSetup(ConfigListScreen, Screen):
 			config.plugins.YouTube.VirtualKeyBoard,
 			_('You can choose what style of VirtualKeyBoard to use it.\nYouTube OR Image (VirtualKeyBoard).')))
 		for p in plugins.getPlugins(where=PluginDescriptor.WHERE_MENU):
-			if 'ServiceApp' in p.path:  # pragma: no cover
+			# TRANSLATORS: Don't translate this! It is used as a variable, so it must be equal to the translation in the plugin!
+			if p.name == _('ServiceApp'):  # pragma: no cover
 				self.list.append(getConfigListEntry(_('Media player:'),
 					config.plugins.YouTube.player,
 					_('Specify the player which will be used for YouTube media playback.')))
